# anti daxuexi

一键生成通知模板以通知全体团支书，及时进行大学习任务

## 功能
 - 获取答案
 - 检测更新
 - 生成通知

## 原理

 解析网页元素

## TODO
 - 排序类题型

## 适用平台

- ✅ 青春浙江

## 更多
 ~~[Android下大学习摸鱼方案](https://blog.shi1011.cn/persummary/1614)~~ 微信版本更新后，x5内核已被删除